==> aar_multi_chip-1.1.10-sources.jar: com/xdja/multichip/process/coveredcard/CCProcessProvider.java <==
package com.xdja.multichip.process.coveredcard;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import java.util.ArrayList;

/**
 * Created by xwy on 2017/9/14.
 */

public class CCProcessProvider extends ContentProvider {
    @Override
    public boolean onCreate() {
        Intent intent = new Intent();
        intent.setClass(getContext(), CCProcessService.class);
        getContext().startService(intent);
        return false;
    }

    @Nullable
    @Override
    public Bundle call(@NonNull String method, @Nullable String arg, @Nullable Bundle extras) {
        Bundle bundle = new Bundle();
        if ("GetJniApiBinder".equals(method)){
            synchronized (CCProcessProvider.class){
                ArrayList<Bundle> list = CCJniApiHandle.getInstance().getCurrentCoveredCardInfo(
                        getContext());
                bundle.putInt("ret",0);
                bundle.putParcelableArrayList("result", list);
                return bundle;
            }
        }
        return super.call(method, arg, extras);
    }

    @Nullable
    @Override
    public Cursor query(@NonNull Uri uri, @Nullable String[] projection, @Nullable String selection, @Nullable String[] selectionArgs, @Nullable String sortOrder) {
        return null;
    }

    @Nullable
    @Override
    public String getType(@NonNull Uri uri) {
        return null;
    }

    @Nullable
    @Override
    public Uri insert(@NonNull Uri uri, @Nullable ContentValues values) {
        return null;
    }

    @Override
    public int delete(@NonNull Uri uri, @Nullable String selection, @Nullable String[] selectionArgs) {
        return 0;
    }

    @Override
    public int update(@NonNull Uri uri, @Nullable ContentValues values, @Nullable String selection, @Nullable String[] selectionArgs) {
        return 0;
    }
}

==> aar_multi_chip-1.1.48-sources.jar: com/xdja/multichip/process/coveredcard/CCProcessProvider.java <==
package com.xdja.multichip.process.coveredcard;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import java.util.ArrayList;

/**
 * Created by xwy on 2017/9/14.
 */

public class CCProcessProvider extends ContentProvider {
    @Override
    public boolean onCreate() {
        Intent intent = new Intent();
        intent.setClass(getContext(), CCProcessService.class);
        getContext().startService(intent);
        return false;
    }

    @Nullable
    @Override
    public Bundle call(@NonNull String method, @Nullable String arg, @Nullable Bundle extras) {
        Bundle bundle = new Bundle();
        if ("GetJniApiBinder".equals(method)){
            increaseFlag();
            synchronized (CCProcessProvider.class){
                ArrayList<Bundle> list = CCJniApiHandle.getInstance().getCurrentCoveredCardInfo(
                        getContext());
                bundle.putInt("ret",0);
                bundle.putParcelableArrayList("result", list);
            }
            decreaseFlag();
            return bundle;
        }
        return super.call(method, arg, extras);
    }

    @Nullable
    @Override
    public Cursor query(@NonNull Uri uri, @Nullable String[] projection, @Nullable String selection, @Nullable String[] selectionArgs, @Nullable String sortOrder) {
        return null;
    }

    @Nullable
    @Override
    public String getType(@NonNull Uri uri) {
        return null;
    }

    @Nullable
    @Override
    public Uri insert(@NonNull Uri uri, @Nullable ContentValues values) {
        return null;
    }

    @Override
    public int delete(@NonNull Uri uri, @Nullable String selection, @Nullable String[] selectionArgs) {
        return 0;
    }

    @Override
    public int update(@NonNull Uri uri, @Nullable ContentValues values, @Nullable String selection, @Nullable String[] selectionArgs) {
        return 0;
    }

    /**
     * add by zhangxiaolong 2018-10-16 10:53:22
     * 主要用于解决主进程provider调用贴膜卡进程provider时，
     * 贴膜卡进程直接exit会影响到主进程。
     */
    private static int callingFlag = 0;
    private static void increaseFlag(){
        synchronized (CCProcessProvider.class){
            ++callingFlag;
        }
    }

    private static void decreaseFlag(){
        synchronized (CCProcessProvider.class){
            --callingFlag;
        }
    }

    public static int getCallingFlag(){
        return callingFlag;
    }
}
